def print_lol2(the_list,level=0):
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol2(each_item,level+1)
        else:
            for tab_stop in range(level):
                 print("\t",end=' ')
            print(each_item)
                



from distutils.core import setup
setup(
    name='nester-compmanwu',
    version='1.2.0',
    py_modules=['nester'],
    author='hfpython',
    author_email='hfpython@headfirstlabs.com',
    url='http://www.headfirstlabs.com',
    description='A simple printer of nested lists',)
